# cnnecharts

cnnecharts 


## 例子








## 功能

- 



## 安装

```
pip install cnnecharts
```



cnnecharts 依赖 Python 这些第三方库(开发者需要安装)：

- [pandas](https://pandas.pydata.org/)



## 前端核心功能使用了这些库(开发者与用户都无须关心)：

- [echart]([Apache ECharts](https://echarts.apache.org/zh/index.html))




